@@ -14,9 +14,9 @@ from wand.version import QUANTUM_DEPTH, MAGICK_VERSION_INFO  # noqa
 
 def test_user_error():
     with raises(TypeError):
-        _ = Color()
+        Color()
     with raises(ValueError):
-        _ = Color('not_a_color')
+        Color('not_a_color')
 
 
 def test_user_raw():
@@ -354,4 +354,4 @@ def test_color_assert_quantum_user_error():
 
 def test_color_repr_html():
     with Color('#AABBCC') as c:
-        assert '#AABBCC' in c._repr_html_()
\ No newline at end of file
+        assert '#AABBCC' in c._repr_html_()
