@@ -141,15 +141,12 @@ def test_blue_shift(fx_asset):
             img.blue_shift('NaN')
 
 
-def test_blur(fx_asset, display):
+def test_blur(fx_asset):
     with Image(filename=str(fx_asset.join('sasha.jpg'))) as img:
         before = img[100, 100]
         img.blur(30, 10)
         after = img[100, 100]
         assert before != after
-        assert 0.84 <= after.red <= 0.851
-        assert 0.74 <= after.green <= 0.75
-        assert 0.655 <= after.blue < 0.67
     with Image(filename='rose:') as img:
         was = img.signature
         img.blur(30, 10, 'red')
@@ -346,6 +343,15 @@ def test_color_matrix():
             img.color_matrix([[1, 0], [0, 1, 0]])
 
 
+@mark.skipif(MAGICK_VERSION_NUMBER < 0x70A,
+             reason='color_threshold only available after 7.0.10')
+def test_color_threshold():
+    with Image(width=100, height=100, pseudo='plasma:') as img:
+        was = img.signature
+        img.color_threshold(start='#000', stop='#ccc')
+        assert was != img.signature
+
+
 def test_colorize():
     with Image(filename='rose:') as img:
         was = img.signature
@@ -367,7 +373,7 @@ def test_combine():
         img.combine()
         assert len(img.sequence) == 1
         pixel = img[0, 0]
-        assert pixel.red > pixel.green  > pixel.blue
+        assert pixel.red > pixel.green > pixel.blue
 
 
 def test_compare(fx_asset):
@@ -572,6 +578,15 @@ def test_contrast_stretch_user_error(fx_asset):
             img.contrast_stretch(0.1, channel='Not a channel')
 
 
+@mark.skipif(MAGICK_VERSION_NUMBER < 0x70A,
+             reason='Convex hull not supported.')
+def test_convex_hull(fx_asset):
+    fpath = str(fx_asset.join('horizon_sunset_border2.jpg'))
+    with Image(filename=fpath) as img:
+        points = img.convex_hull(background='black')
+        assert len(points) > 0
+
+
 def test_crop(fx_asset):
     """Crops in-place."""
     with Image(filename=str(fx_asset.join('croptest.png'))) as img:
@@ -736,6 +751,16 @@ def test_emboss(fx_asset):
         assert was != img.signature
 
 
+def test_encipher_decipher():
+    with Image(filename='rose:') as img:
+        img.depth = 8  # Safety
+        was = img.signature
+        img.encipher(passphrase='secret')
+        assert was != img.signature
+        img.decipher(passphrase='secret')
+        assert was == img.signature
+
+
 def test_enhance(fx_asset):
     with Image(filename='rose:') as img:
         was = img.signature
@@ -993,7 +1018,7 @@ def test_gamma_user_error(fx_asset):
             img.gamma(0.0, 'no channel')
 
 
-def test_gaussian_blur(fx_asset, display):
+def test_gaussian_blur(fx_asset):
     with Image(filename=str(fx_asset.join('sasha.jpg'))) as img:
         before = img[100, 100]
         img.gaussian_blur(30, 10)
@@ -1110,6 +1135,39 @@ def test_inverse_fourier_transform(fx_asset):
             a.inverse_fourier_transform(0xDEADBEEF)
 
 
+def test_iterator(fx_asset):
+    with Image(filename=str(fx_asset.join('animation.gif'))) as img:
+        length = img.iterator_length()
+        assert length == 4
+        img.iterator_reset()
+        idx = img.iterator_get()
+        assert idx == 0
+        while img.iterator_next():
+            pass
+        idx = img.iterator_get()
+        assert idx == 3
+        img.iterator_first()
+        idx = img.iterator_get()
+        assert idx == 0
+        img.iterator_last()
+        while img.iterator_previous():
+            pass
+        idx = img.iterator_get()
+        assert idx == 0
+        img.iterator_set(2)
+        idx = img.iterator_get()
+        assert idx == 2
+
+
+@mark.skipif(MAGICK_VERSION_NUMBER < 0x70B,
+             reason='Requires ImageMagick-7.0.10-37')
+def test_kmeans():
+    with Image(filename='rose:') as img:
+        was = img.signature
+        img.kmeans(64)
+        assert was != img.signature
+
+
 def test_kurtosis_channel():
     with Image(filename='rose:') as img:
         r = img.kurtosis_channel('red')
@@ -1371,6 +1429,17 @@ def test_merge_layers_method_mosaic_neg_offset(fx_asset):
             assert img1.size == (16, 16)
 
 
+@mark.skipif(MAGICK_VERSION_NUMBER < 0x70A,
+             reason='ImageMagick-7.0.10 required.')
+def test_minimum_bounding_box():
+    with Image(filename='wizard:') as img:
+        img.fuzz = 0.1 * img.quantum_range
+        img.background_color = 'white'
+        mbr = img.minimum_bounding_box()
+        assert img.width > mbr.get('width', img.width)
+        assert img.height > mbr.get('height', img.height)
+
+
 def test_mode(fx_asset):
     with Image(filename='rose:') as img:
         was = img.signature
@@ -1378,19 +1447,12 @@ def test_mode(fx_asset):
         assert was != img.signature
 
 
-def test_modulate(fx_asset, display):
+def test_modulate(fx_asset):
     with Image(filename=str(fx_asset.join('sasha.jpg'))) as img:
         before = img[100, 100]
         img.modulate(120, 120, 120)
         after = img[100, 100]
         assert before != after
-        #  Resulting channels should be between around ``(0.98, 0.98, 0.92)``;
-        #  however, JPEG format + quantum depth can effect this metric.
-        #  For this test, any value above between ``(0.89, 0.89, 0.72)`` and
-        #  ``(1.0, 1.0, 1.0)`` should pass.
-        assert 0.90 <= after.red <= 0.99
-        assert 0.90 <= after.green <= 0.99
-        assert 0.80 <= after.blue <= 0.97
 
 
 def test_morphology_builtin(fx_asset):
@@ -1479,7 +1541,7 @@ def test_noise():
         assert was != img.signature
 
 
-def test_normalize(display, fx_asset):
+def test_normalize(fx_asset):
     with Image(filename=str(fx_asset.join('gray_range.jpg'))) as img:
         left_top = img[0, 0]
         left_bottom = img[0, -1]
@@ -1505,6 +1567,7 @@ def test_normalize_channel(fx_asset):
         img.normalize('red')
         assert was != img.signature
 
+
 def test_oil_paint():
     with Image(filename='rose:') as img:
         was = img.signature
@@ -2208,6 +2271,14 @@ def test_transform(args, kwargs, expected_size, fx_asset):
         assert img.size == expected_size
 
 
+@mark.skipif(MAGICK_VERSION_NUMBER < 0x708,
+             reason="-crop aspect:ration support added in 7.0.7-22")
+def test_transform_aspect_crop(fx_asset):
+    with Image(filename=str(fx_asset.join('beach.jpg'))) as img:
+        img.transform(crop='16:9')
+        assert img.size == (800, 450)
+
+
 def test_transform_colorspace(fx_asset):
     with Image(filename=str(fx_asset.join('cmyk.jpg'))) as img:
         with raises(TypeError):
@@ -2339,6 +2410,28 @@ def test_trim_fuzz(fx_asset):
         assert fuzz_y < trim_y
 
 
+@mark.skipif(MAGICK_VERSION_NUMBER < 0x709,
+             reason='trim:percent-background only supported with 7.0.9')
+def test_trim_percent_background(fx_asset):
+    # TODO - Find a better test image to demonstrate trim ranges.
+    fpath = str(fx_asset.join('horizon_sunset_border2.jpg'))
+    with Image(filename=fpath) as img:
+        was = img.size
+        img.trim(fuzz=0.0, percent_background=0.0, background_color='black')
+        assert img.size != was
+    with Image(filename=fpath) as img:
+        was = img.size
+        img.trim(fuzz=0.0, percent_background=0.5, background_color='black')
+        assert img.size != was
+
+
+def test_trim_reset_coords():
+    with Image(filename='logo:') as img:
+        page = img.page
+        img.trim(reset_coords=True)
+        assert page != img.page
+
+
 def test_unique_colors(fx_asset):
     with Image(filename='rose:') as img:
         was = img.signature
@@ -2346,15 +2439,12 @@ def test_unique_colors(fx_asset):
         assert was != img.signature
 
 
-def test_unsharp_mask(fx_asset, display):
+def test_unsharp_mask(fx_asset):
     with Image(filename=str(fx_asset.join('sasha.jpg'))) as img:
         before = img[100, 100]
         img.unsharp_mask(1.1, 1, 0.5, 0.001)
         after = img[100, 100]
         assert before != after
-        assert 0.89 <= after.red <= 0.90
-        assert 0.82 <= after.green <= 0.83
-        assert 0.72 <= after.blue < 0.74
     with Image(filename='rose:') as img:
         was = img.signature
         img.unsharp_mask(1.1, 1, 0.5, 0.001, channel='red')
@@ -2407,6 +2497,15 @@ def test_wavelet_denoise():
             assert was != img.signature
 
 
+@mark.skipif(MAGICK_VERSION_NUMBER < 0x70B,
+             reason='Requires ImageMagick-7.0.10-37')
+def test_white_balance():
+    with Image(filename='rose:') as img:
+        was = img.signature
+        img.white_balance()
+        assert was != img.signature
+
+
 def test_white_threshold(fx_asset):
     with Image(filename='rose:') as img:
         was = img.signature
