@@ -72,8 +72,6 @@ def test_blank_image():
 def test_raw_image(fx_asset):
     b = b"".join([struct.pack("BBB", i, j, 0)
                   for i in range(256) for j in range(256)])
-    with raises(ValueError):
-        Image(blob=b, depth=6)
     with raises(ValueError):
         Image(blob=b, depth=8, width=0, height=0, format="RGB")
     with raises(TypeError):
@@ -140,6 +138,14 @@ def test_read_with_colorspace(fx_asset):
         assert img.units == 'pixelspercentimeter'
 
 
+def test_read_with_extract():
+    with Image(filename='rose:', extract="10x10+10+10") as img:
+        assert (10, 10) == img.size
+    with Image() as img:
+        img.read(filename='rose:', extract="10x10+10+10")
+        assert (10, 10) == img.size
+
+
 def test_new_from_file(fx_asset):
     """Opens an image from the file object."""
     with fx_asset.join('mona-lisa.jpg').open('rb') as f:
@@ -564,7 +570,17 @@ def test_array_interface():
     with Image(filename='rose:') as img:
         img.alpha_channel = 'off'
         array = np.array(img)
-        assert array.shape == (70, 46, 3)
+        assert array.shape == (46, 70, 3)
+    with Image(filename='rose:') as img:
+        img.alpha_channel = 'off'
+        img.transform_colorspace('gray')
+        array = np.array(img)
+        assert array.shape == (46, 70, 1)
+    with Image(filename='rose:') as img:
+        img.alpha_channel = 'off'
+        img.transform_colorspace('cmyk')
+        array = np.array(img)
+        assert array.shape == (46, 70, 4)
 
 
 @mark.skipif(np is None, reason='Numpy not available.')
@@ -572,3 +588,10 @@ def test_numpy_array_hairpinning():
     with Image(filename='rose:') as left:
         with Image.from_array(left) as right:
             assert left.size == right.size
+
+
+def test_data_url():
+    with Image(filename='rose:') as img:
+        img.format = 'PNG'
+        data = img.data_url()
+        assert data.startswith('data:image/png;base64,')
