@@ -217,8 +217,12 @@ class Drawing(Resource):
            :c:func:`MagickRelinquishMemory` instead of :c:func:`libc.free`.
 
         """
+        clip_path_str = None
         clip_path_p = library.DrawGetClipPath(self.resource)
-        return text(clip_path_p.value)
+        if clip_path_p:
+            clip_path_str = text(ctypes.string_at(clip_path_p))
+            clip_path_p = library.MagickRelinquishMemory(clip_path_p)
+        return clip_path_str
 
     @clip_path.setter
     def clip_path(self, path):
@@ -324,8 +328,12 @@ class Drawing(Resource):
            :c:func:`MagickRelinquishMemory` instead of :c:func:`libc.free`.
 
         """
+        font_str = None
         font_p = library.DrawGetFont(self.resource)
-        return text(font_p.value)
+        if font_p:
+            font_str = text(ctypes.string_at(font_p))
+            font_p = library.MagickRelinquishMemory(font_p)
+        return font_str
 
     @font.setter
     def font(self, font):
@@ -343,8 +351,12 @@ class Drawing(Resource):
            :c:func:`MagickRelinquishMemory` instead of :c:func:`libc.free`.
 
         """
+        font_family_str = None
         font_family_p = library.DrawGetFontFamily(self.resource)
-        return text(font_family_p.value)
+        if font_family_p:
+            font_family_str = text(ctypes.string_at(font_family_p))
+            font_family_p = library.MagickRelinquishMemory(font_family_p)
+        return font_family_str
 
     @font_family.setter
     def font_family(self, family):
@@ -366,10 +378,7 @@ class Drawing(Resource):
 
     @font_resolution.setter
     def font_resolution(self, resolution):
-        if not isinstance(resolution, abc.Sequence):
-            raise TypeError('expected sequence, not ' + repr(resolution))
-        if len(resolution) != 2:
-            raise ValueError('expected sequence of 2 floats')
+        assertions.assert_coordinate(font_resolution=resolution)
         library.DrawSetFontResolution(self.resource, *resolution)
 
     @property
@@ -516,8 +525,8 @@ class Drawing(Resource):
 
     @property
     def stroke_dash_array(self):
-        """(:class:`~collections.abc.Sequence`) - (:class:`numbers.Real`) An array
-        representing the pattern of dashes & gaps used to stroke paths.
+        """(:class:`~collections.abc.Sequence`) - (:class:`numbers.Real`) An
+        array representing the pattern of dashes & gaps used to stroke paths.
         It also can be set.
 
         .. versionadded:: 0.4.0
@@ -532,10 +541,10 @@ class Drawing(Resource):
             self.resource, ctypes.byref(number_elements)
         )
         dash_array = []
-        if dash_array_p is not None:
+        if dash_array_p:
             dash_array = [float(dash_array_p[i])
                           for i in xrange(number_elements.value)]
-            library.MagickRelinquishMemory(dash_array_p)
+            dash_array_p = library.MagickRelinquishMemory(dash_array_p)
         return dash_array
 
     @stroke_dash_array.setter
@@ -732,8 +741,12 @@ class Drawing(Resource):
            :c:func:`MagickRelinquishMemory` instead of :c:func:`libc.free`.
 
         """
+        text_encoding_str = None
         text_encoding_p = library.DrawGetTextEncoding(self.resource)
-        return text(text_encoding_p.value)
+        if text_encoding_p:
+            text_encoding_str = text(ctypes.string_at(text_encoding_p))
+            text_encoding_p = library.MagickRelinquishMemory(text_encoding_p)
+        return text_encoding_str
 
     @text_encoding.setter
     def text_encoding(self, encoding):
@@ -829,8 +842,13 @@ class Drawing(Resource):
            :c:func:`MagickRelinquishMemory` instead of :c:func:`libc.free`.
 
         """
-        vector_graphics_p = library.DrawGetVectorGraphics(self.resource)
-        return '<wand>' + text(vector_graphics_p.value) + '</wand>'
+        vg_p = library.DrawGetVectorGraphics(self.resource)
+        if vg_p:
+            vg_str = ctypes.string_at(vg_p)
+            vg_p = library.MagickRelinquishMemory(vg_p)
+        else:
+            vg_str = b''
+        return '<wand>' + text(vg_str) + '</wand>'
 
     @vector_graphics.setter
     def vector_graphics(self, vector_graphics):
@@ -903,13 +921,12 @@ class Drawing(Resource):
                 'Method added with ImageMagick version 7. ' +
                 'Please use `wand.drawing.Drawing.matte()\' instead.'
             )
-        if x is None or y is None:
-            raise TypeError('Both x & y coordinates need to be defined')
+        assertions.assert_real(x=x, y=y)
         assertions.string_in_list(PAINT_METHOD_TYPES,
                                   'wand.drawing.PAINT_METHOD_TYPES',
                                   paint_method=paint_method)
-        library.DrawAlpha(self.resource, float(x), float(y),
-                          PAINT_METHOD_TYPES.index(paint_method))
+        op = PAINT_METHOD_TYPES.index(paint_method)
+        library.DrawAlpha(self.resource, x, y, op)
 
     def arc(self, start, end, degree):
         """Draws a arc using the current :attr:`stroke_color`,
@@ -928,6 +945,7 @@ class Drawing(Resource):
         .. versionadded:: 0.4.0
 
         """
+        assertions.assert_coordinate(start=start, end=end, degree=degree)
         start_x, start_y = start
         end_x, end_y = end
         degree_start, degree_end = degree
@@ -980,11 +998,11 @@ class Drawing(Resource):
         .. versionadded:: 0.4.0
 
         """
+        assertions.assert_coordinate(origin=origin, perimeter=perimeter)
         origin_x, origin_y = origin
         perimeter_x, perimeter_y = perimeter
-        library.DrawCircle(self.resource,
-                           float(origin_x), float(origin_y),  # origin
-                           float(perimeter_x), float(perimeter_y))  # perimeter
+        library.DrawCircle(self.resource, origin_x, origin_y,
+                           perimeter_x, perimeter_y)
 
     def clear(self):
         library.ClearDrawingWand(self.resource)
@@ -998,7 +1016,7 @@ class Drawing(Resource):
         """
         return type(self)(drawing=self)
 
-    def color(self, x=None, y=None, paint_method='undefined'):
+    def color(self, x=0.0, y=0.0, paint_method='undefined'):
         """Draws a color on the image using current fill color, starting
         at specified position & method.
 
@@ -1014,13 +1032,12 @@ class Drawing(Resource):
         .. versionadded:: 0.4.0
 
         """
-        if x is None or y is None:
-            raise TypeError('Both x & y coordinates need to be defined')
+        assertions.assert_real(x=x, y=y)
         assertions.string_in_list(PAINT_METHOD_TYPES,
                                   'wand.drawing.PAINT_METHOD_TYPES',
                                   paint_method=paint_method)
-        library.DrawColor(self.resource, float(x), float(y),
-                          PAINT_METHOD_TYPES.index(paint_method))
+        op = PAINT_METHOD_TYPES.index(paint_method)
+        library.DrawColor(self.resource, x, y, op)
 
     def comment(self, message=None):
         """Adds a comment to the vector stream.
@@ -1060,16 +1077,13 @@ class Drawing(Resource):
         """
         assertions.assert_string(operator=operator)
         assertions.assert_real(left=left, top=top, width=width, height=height)
-        try:
-            op = COMPOSITE_OPERATORS.index(operator)
-        except IndexError:
-            raise IndexError(repr(operator) + ' is an invalid composite '
-                             'operator type; see wand.image.COMPOSITE_'
-                             'OPERATORS dictionary')
-        okay = library.DrawComposite(self.resource, op, left, top, width,
-                                     height, image.wand)
-        if okay == 0:
-            self.raise_exception()
+        assertions.string_in_list(COMPOSITE_OPERATORS,
+                                  'wand.drawing.COMPOSITE_OPERATORS',
+                                  operator=operator)
+        op = COMPOSITE_OPERATORS.index(operator)
+        library.DrawComposite(self.resource, op, left, top, width,
+                              height, image.wand)
+        self.raise_exception()
 
     def draw(self, image):
         """Renders the current drawing into the ``image``.  You can simply
@@ -1100,7 +1114,7 @@ class Drawing(Resource):
         if not res:
             self.raise_exception()
 
-    def ellipse(self, origin, radius, rotation=(0, 360)):
+    def ellipse(self, origin, radius, rotation=None):
         """Draws a ellipse at ``origin`` with independent x & y ``radius``.
         Ellipse can be partial by setting start & end ``rotation``.
 
@@ -1118,13 +1132,17 @@ class Drawing(Resource):
         .. versionadded:: 0.4.0
 
         """
+        if rotation is None:
+            rotation = (0, 360)
+        assertions.assert_coordinate(origin=origin, radius=radius,
+                                     rotation=rotation)
         origin_x, origin_y = origin
         radius_x, radius_y = radius
         rotation_start, rotation_end = rotation
         library.DrawEllipse(self.resource,
-                            float(origin_x), float(origin_y),  # origin
-                            float(radius_x), float(radius_y),  # radius
-                            float(rotation_start), float(rotation_end))
+                            origin_x, origin_y,
+                            radius_x, radius_y,
+                            rotation_start, rotation_end)
 
     def get_font_metrics(self, image, text, multiline=False):
         """Queries font metrics from the given ``text``.
@@ -1159,7 +1177,7 @@ class Drawing(Resource):
             # Generate a generic error if ImageMagick couldn't emit one.
             raise ValueError('Unable to render text with current font.')
         args = [result[i] for i in xrange(13)]
-        library.MagickRelinquishMemory(result)
+        result = library.MagickRelinquishMemory(result)
         return FontMetrics(*args)
 
     def line(self, start, end):
@@ -1179,7 +1197,7 @@ class Drawing(Resource):
                          int(start_x), int(start_y),
                          int(end_x), int(end_y))
 
-    def matte(self, x=None, y=None, paint_method='undefined'):
+    def matte(self, x=0.0, y=0.0, paint_method='undefined'):
         """Paints on the image's opacity channel in order to set effected pixels
         to transparent.
 
@@ -1206,13 +1224,12 @@ class Drawing(Resource):
                 'Method removed from ImageMagick version. ' +
                 'Please use `wand.drawing.Drawing.alpha()\' instead.'
             )
-        if x is None or y is None:
-            raise TypeError('Both x & y coordinates need to be defined')
+        assertions.assert_real(x=x, y=y)
         assertions.string_in_list(PAINT_METHOD_TYPES,
                                   'wand.drawing.PAINT_METHOD_TYPES',
                                   paint_method=paint_method)
-        library.DrawMatte(self.resource, float(x), float(y),
-                          PAINT_METHOD_TYPES.index(paint_method))
+        op = PAINT_METHOD_TYPES.index(paint_method)
+        library.DrawMatte(self.resource, x, y, op)
 
     def path_close(self):
         """Adds a path element to the current path which closes
@@ -1411,12 +1428,11 @@ class Drawing(Resource):
         .. versionadded:: 0.4.0
 
         """
-        if x is None:
-            raise TypeError('x is missing')
+        assertions.assert_real(x=x)
         if relative:
-            library.DrawPathLineToHorizontalRelative(self.resource, float(x))
+            library.DrawPathLineToHorizontalRelative(self.resource, x)
         else:
-            library.DrawPathLineToHorizontalAbsolute(self.resource, float(x))
+            library.DrawPathLineToHorizontalAbsolute(self.resource, x)
         return self
 
     def path_line(self, to=None, relative=False):
@@ -1435,13 +1451,12 @@ class Drawing(Resource):
         .. versionadded:: 0.4.0
 
         """
-        if to is None:
-            raise TypeError('to is missing')
+        assertions.assert_coordinate(to=to)
         x, y = to
         if relative:
-            library.DrawPathLineToRelative(self.resource, float(x), float(y))
+            library.DrawPathLineToRelative(self.resource, x, y)
         else:
-            library.DrawPathLineToAbsolute(self.resource, float(x), float(y))
+            library.DrawPathLineToAbsolute(self.resource, x, y)
         return self
 
     def path_move(self, to=None, relative=False):
@@ -1459,13 +1474,12 @@ class Drawing(Resource):
         .. versionadded:: 0.4.0
 
         """
-        if to is None:
-            raise TypeError('to is missing')
+        assertions.assert_coordinate(to=to)
         x, y = to
         if relative:
-            library.DrawPathMoveToRelative(self.resource, float(x), float(y))
+            library.DrawPathMoveToRelative(self.resource, x, y)
         else:
-            library.DrawPathMoveToAbsolute(self.resource, float(x), float(y))
+            library.DrawPathMoveToAbsolute(self.resource, x, y)
         return self
 
     def path_start(self):
@@ -1497,12 +1511,11 @@ class Drawing(Resource):
         .. versionadded:: 0.4.0
 
         """
-        if y is None:
-            raise TypeError('y is missing')
+        assertions.assert_real(y=y)
         if relative:
-            library.DrawPathLineToVerticalRelative(self.resource, float(y))
+            library.DrawPathLineToVerticalRelative(self.resource, y)
         else:
-            library.DrawPathLineToVerticalAbsolute(self.resource, float(y))
+            library.DrawPathLineToVerticalAbsolute(self.resource, y)
         return self
 
     def polygon(self, points=None):
@@ -1558,9 +1571,8 @@ class Drawing(Resource):
         .. versionadded:: 0.4.0
 
         """
-        library.DrawPoint(self.resource,
-                          float(x),
-                          float(y))
+        assertions.assert_real(x=x, y=y)
+        library.DrawPoint(self.resource, x, y)
 
     def pop(self):
         """Pop destroys the current tip of the drawing context stack,
@@ -1573,12 +1585,15 @@ class Drawing(Resource):
             or alter, any previously executed drawing commands.
 
         :returns: success of pop operation.
-        :rtype: `bool`
+        :rtype: :class:`bool`
 
         .. versionadded:: 0.4.0
 
         """
-        return bool(library.PopDrawingWand(self.resource))
+        ok = bool(library.PopDrawingWand(self.resource))
+        if not ok:  # pragma: no cover
+            self.raise_exception()
+        return ok
 
     def pop_clip_path(self):
         """Terminates a clip path definition.
@@ -1651,12 +1666,15 @@ class Drawing(Resource):
             drawn artifacts.
 
         :returns: success of push operation.
-        :rtype: `bool`
+        :rtype: :class:`bool`
 
         .. versionadded:: 0.4.0
 
         """
-        return bool(library.PushDrawingWand(self.resource))
+        ok = bool(library.PushDrawingWand(self.resource))
+        if not ok:
+            self.raise_exception()
+        return ok
 
     def push_clip_path(self, clip_mask_id):
         """Starts a clip path definition which is comprised of any number of
@@ -1700,7 +1718,7 @@ class Drawing(Resource):
         :param height: height of pattern space.
         :type height: :class:`numbers.Real`
         :returns: success of push operation
-        :rtype: `bool`
+        :rtype: :class:`bool`
 
         .. versionadded:: 0.4.0
 
@@ -1710,6 +1728,8 @@ class Drawing(Resource):
         okay = library.DrawPushPattern(self.resource, binary(pattern_id),
                                        left, top,
                                        width, height)
+        if not okay:  # pragma: no cover
+            self.raise_exception()
         return bool(okay)
 
     def rectangle(self, left=None, top=None, right=None, bottom=None,
@@ -1825,7 +1845,7 @@ class Drawing(Resource):
             library.DrawRectangle(self.resource, left, top, right, bottom)
         self.raise_exception()
 
-    def rotate(self, degree):
+    def rotate(self, degree=0.0):
         """Applies the specified rotation to the current coordinate space.
 
         :param degree: degree to rotate
@@ -1837,14 +1857,14 @@ class Drawing(Resource):
         assertions.assert_real(degree=degree)
         library.DrawRotate(self.resource, degree)
 
-    def scale(self, x=None, y=None):
+    def scale(self, x=1.0, y=1.0):
         """
         Adjusts the scaling factor to apply in the horizontal and vertical
         directions to the current coordinate space.
 
-        :param x: Horizontal scale factor
+        :param x: Horizontal scale factor. Default `1.0`
         :type x: :class:`~numbers.Real`
-        :param y: Vertical scale factor
+        :param y: Vertical scale factor. Default `1.0`
         :type y: :class:`~numbers.Real`
 
         .. versionadded:: 0.4.0
@@ -1869,10 +1889,8 @@ class Drawing(Resource):
         if url[0] != '#':
             raise ValueError('value not a relative URL, '
                              'expecting "#identifier"')
-        okay = library.DrawSetFillPatternURL(self.resource, binary(url))
-        if okay == 0:
-            # ThrowDrawException(DrawError,"URLNotFound",fill_url)
-            self.raise_exception()
+        library.DrawSetFillPatternURL(self.resource, binary(url))
+        self.raise_exception()
 
     def set_stroke_pattern_url(self, url):
         """Sets the pattern used for stroking object outlines. Only local
@@ -1890,10 +1908,8 @@ class Drawing(Resource):
         if url[0] != '#':
             raise ValueError('value not a relative URL, '
                              'expecting "#identifier"')
-        okay = library.DrawSetStrokePatternURL(self.resource, binary(url))
-        if okay == 0:
-            # ThrowDrawException(DrawError,"URLNotFound",fill_url)
-            self.raise_exception()
+        library.DrawSetStrokePatternURL(self.resource, binary(url))
+        self.raise_exception()
 
     def skew(self, x=None, y=None):
         """Skews the current coordinate system in the horizontal direction if
@@ -1908,9 +1924,11 @@ class Drawing(Resource):
 
         """
         if x is not None:
-            library.DrawSkewX(self.resource, float(x))
+            assertions.assert_real(x=x)
+            library.DrawSkewX(self.resource, x)
         if y is not None:
-            library.DrawSkewY(self.resource, float(y))
+            assertions.assert_real(y=y)
+            library.DrawSkewY(self.resource, y)
 
     def text(self, x, y, body):
         """Writes a text ``body`` into (``x``, ``y``).
@@ -1940,7 +1958,7 @@ class Drawing(Resource):
             ctypes.cast(body_p, ctypes.POINTER(ctypes.c_ubyte))
         )
 
-    def translate(self, x=None, y=None):
+    def translate(self, x=0.0, y=0.0):
         """Applies a translation to the current coordinate system which moves
         the coordinate system origin to the specified coordinate.
 
@@ -1951,9 +1969,8 @@ class Drawing(Resource):
 
         .. versionadded:: 0.4.0
         """
-        if x is None or y is None:
-            raise TypeError('Both x & y coordinates need to be defined')
-        library.DrawTranslate(self.resource, float(x), float(y))
+        assertions.assert_real(x=x, y=y)
+        library.DrawTranslate(self.resource, x, y)
 
     def viewbox(self, left, top, right, bottom):
         """Viewbox sets the overall canvas size to be recorded with the drawing
@@ -2002,7 +2019,7 @@ def _list_to_point_info(points):
     point_info_size = point_length * tuple_size
     # Allocate sequence of memory
     point_info = (ctypes.c_double * point_info_size)()
-    for double_index in range(point_info_size):
+    for double_index in xrange(point_info_size):
         tuple_index = double_index // tuple_size
         tuple_offset = double_index % tuple_size
         point_info[double_index] = ctypes.c_double(
