@@ -5,17 +5,18 @@ There is the global resource to manage in MagickWand API. This module
 implements automatic global resource management through reference counting.
 
 """
+import atexit
 import contextlib
 import ctypes
 import warnings
 
 from .api import library
-from .compat import string_type
+from .compat import abc, string_type
 from .exceptions import TYPE_MAP, WandException
+from .version import MAGICK_VERSION_NUMBER
 
-
-__all__ = ('genesis', 'terminus', 'increment_refcount', 'decrement_refcount',
-           'Resource', 'DestroyedResourceError')
+__all__ = ('genesis', 'limits', 'shutdown', 'terminus',
+           'DestroyedResourceError', 'Resource', 'ResourceLimits')
 
 
 def genesis():
@@ -39,44 +40,42 @@ def terminus():
        :func:`decrement_refcount()` functions instead.
 
     """
-    library.MagickWandTerminus()
+    if library.IsMagickWandInstantiated is None:  # pragma no cover
+        library.MagickWandTerminus()
+    elif library.IsMagickWandInstantiated():
+        library.MagickWandTerminus()
 
 
-#: (:class:`numbers.Integral`) The internal integer value that maintains
-#: the number of referenced objects.
-#:
-#: .. warning::
-#:
-#:    Don't touch this global variable. Use :func:`increment_refcount()` and
-#:    :func:`decrement_refcount()` functions instead.
-#:
-reference_count = 0
+allocation_map = {}
 
 
-def increment_refcount():
-    """Increments the :data:`reference_count` and instantiates the MagickWand
-    API if it is the first use.
-
-    """
-    global reference_count
-    if reference_count:
-        reference_count += 1
-    else:
+def allocate_ref(addr, deallocator):
+    global allocation_map
+    if len(allocation_map) == 0:
         genesis()
-        reference_count = 1
+    if addr:
+        allocation_map[addr] = deallocator
 
 
-def decrement_refcount():
-    """Decrements the :data:`reference_count` and cleans up the MagickWand
-    API if it will be no more used.
+def deallocate_ref(addr):
+    global allocation_map
+    if addr in list(allocation_map):
+        deallocator = allocation_map.pop(addr)
+        if callable(deallocator):
+            deallocator(addr)
 
-    """
-    global reference_count
-    if not reference_count:
-        raise RuntimeError('wand.resource.reference_count is already zero')
-    reference_count -= 1
-    if not reference_count:
-        terminus()
+
+@atexit.register
+def shutdown():
+    global allocation_map
+    for addr in list(allocation_map):
+        try:
+            deallocator = allocation_map.pop(addr)
+            if callable(deallocator):
+                deallocator(addr)
+        except KeyError:
+            pass
+    terminus()
 
 
 class Resource(object):
@@ -106,7 +105,7 @@ class Resource(object):
 
     #: (:class:`ctypes.CFUNCTYPE`) The :mod:`ctypes` predicate function
     #: that returns whether the given pointer (that contains a resource data
-    #: usuaully) is a valid resource.
+    #: usually) is a valid resource.
     #:
     #: .. note::
     #:
@@ -159,13 +158,14 @@ class Resource(object):
 
         if self.c_is_resource(resource):
             self.c_resource = resource
+            allocate_ref(self.c_resource, self.c_destroy_resource)
         else:
             raise TypeError(repr(resource) + ' is an invalid resource')
-        increment_refcount()
 
     @resource.deleter
     def resource(self):
-        self.c_destroy_resource(self.resource)
+        if getattr(self, 'c_resource', None):
+            deallocate_ref(self.c_resource)
         self.c_resource = None
 
     @contextlib.contextmanager
@@ -178,12 +178,7 @@ class Resource(object):
                 resource.resource = library.NewResource()
 
         """
-        increment_refcount()
-        try:
-            yield self
-        except:
-            decrement_refcount()
-            raise
+        yield self
 
     def destroy(self):
         """Cleans up the resource explicitly. If you use the resource in
@@ -192,7 +187,6 @@ class Resource(object):
 
         """
         del self.resource
-        decrement_refcount()
 
     def get_exception(self):
         """Gets a current exception instance.
@@ -205,10 +199,16 @@ class Resource(object):
         severity = ctypes.c_int()
         desc = self.c_get_exception(self.resource, ctypes.byref(severity))
         if severity.value == 0:
+            if desc:
+                desc = library.MagickRelinquishMemory(desc)
             return
-        self.c_clear_exception(self.wand)
+        self.c_clear_exception(self.resource)
         exc_cls = TYPE_MAP[severity.value]
-        message = desc.value
+        if desc:
+            message = ctypes.string_at(desc)
+            desc = library.MagickRelinquishMemory(desc)
+        else:
+            message = b''
         if not isinstance(message, string_type):
             message = message.decode(errors='replace')
         return exc_cls(message)
@@ -221,6 +221,9 @@ class Resource(object):
         elif isinstance(e, Exception):
             raise e
 
+    def make_blob(self, format=None):
+        raise NotImplementedError
+
     def __enter__(self):
         return self
 
@@ -242,3 +245,132 @@ class DestroyedResourceError(WandException, ReferenceError, AttributeError):
        It becomes a subtype of :exc:`wand.exceptions.WandException`.
 
     """
+
+
+class ResourceLimits(abc.MutableMapping):
+    """Wrapper for MagickCore resource limits.
+    Useful for dynamically reducing system resources before attempting risky,
+    or slow running, :class:`~wand.image.Image` operations.
+
+    For example::
+
+       from wand.image import Image
+       from wand.resource import limits
+
+       # Use 100MB of ram before writing temp data to disk.
+       limits['memory'] = 1024 * 1024 * 100
+       # Reject images larger than 1000x1000.
+       limits['width'] = 1000
+       limits['height'] = 1000
+
+       # Debug resources used.
+       with Image(filename='user.jpg') as img:
+           print('Using {0} of {1} memory'.format(limits.resource('memory'),
+                                                  limits['memory']))
+
+       # Dump list of all limits.
+       for label in limits:
+           print('{0} => {1}'.format(label, limits[label]))
+
+    Available resource keys:
+
+    - ``'area'`` - Maximum `width * height` of a pixel cache before writing to
+      disk.
+    - ``'disk'`` - Maximum bytes used by pixel cache on disk before exception
+      is thrown.
+    - ``'file'`` - Maximum cache files opened at any given time.
+    - ``'height'`` - Maximum height of image before exception is thrown.
+    - ``'list_length'`` - Maximum images in sequence. Only available with
+      recent version of ImageMagick.
+    - ``'map'`` - Maximum memory map in bytes to allocated for pixel cache
+      before using disk.
+    - ``'memory'`` - Maximum bytes to allocated for pixel cache before using
+      disk.
+    - ``'thread'`` - Maximum parallel task sub-routines can spawn - if using
+      OpenMP.
+    - ``'throttle'`` - Total milliseconds to yield to CPU - if possible.
+    - ``'time'`` - Maximum seconds before exception is thrown.
+    - ``'width'`` - Maximum width of image before exception is thrown.
+
+    .. versionadded:: 0.5.1
+    """
+
+    #: (:class:`tuple`) List of available resource types for ImageMagick-6.
+    _limits6 = ('undefined', 'area', 'disk', 'file', 'map', 'memory', 'thread',
+                'time', 'throttle', 'width', 'height')
+
+    #: (:class:`tuple`) List of available resource types for ImageMagick-7.
+    _limits7 = ('undefined', 'area', 'disk', 'file', 'height', 'map', 'memory',
+                'thread', 'throttle', 'time', 'width', 'list_length')
+
+    def __init__(self):
+        if MAGICK_VERSION_NUMBER < 0x700:
+            self.limits = self._limits6
+        else:
+            self.limits = self._limits7
+
+    def __getitem__(self, r):
+        return self.get_resource_limit(r)
+
+    def __setitem__(self, r, v):
+        self.set_resource_limit(r, v)
+
+    def __delitem__(self, r):
+        self[r] = 0
+
+    def __iter__(self):
+        return iter(self.limits)
+
+    def __len__(self):
+        return len(self.limits)
+
+    def _to_idx(self, resource):
+        """Helper method to map resource string to enum value."""
+        return self.limits.index(resource)
+
+    def resource(self, resource):
+        """Get the current value for the resource type.
+
+        :param resource: Resource type.
+        :type resource: :class:`basestring`
+        :rtype: :class:`numeric.Integral`
+
+        .. versionadded:: 0.5.1
+        """
+        return library.MagickGetResource(self._to_idx(resource))
+
+    def get_resource_limit(self, resource):
+        """Get the current limit for the resource type.
+
+        :param resource: Resource type.
+        :type resource: :class:`basestring`
+        :rtype: :class:`numeric.Integral`
+
+        .. versionadded:: 0.5.1
+        """
+        return library.MagickGetResourceLimit(self._to_idx(resource))
+
+    def set_resource_limit(self, resource, limit):
+        """Sets a new limit for resource type.
+
+        .. note::
+
+            The new limit value must be equal to, or less then, the maximum
+            limit defined by the :file:`policy.xml`. Any values set outside
+            normal bounds will be ignored silently.
+
+        :param resource: Resource type.
+        :type resource: :class:`basestring`
+        :param limit: New limit value.
+        :type limit: :class:`numeric.Integral`
+
+        .. versionadded:: 0.5.1
+        """
+        genesis()
+        library.MagickSetResourceLimit(self._to_idx(resource), int(limit))
+
+
+#: (:class:`ResourceLimits`) Helper to get & set Magick Resource Limits.
+#:
+#: .. versionadded:: 0.5.1
+limits = ResourceLimits()
